{-# LANGUAGE CPP #-}

-------------------------------------------------------------------------------
--
-- | Platform constants
--
-- (c) The University of Glasgow 2013
--
-------------------------------------------------------------------------------

module PlatformConstants (PlatformConstants(..)) where

-- Produced by deriveConstants
#include "GHCConstantsHaskellType.hs"

